@@ -34,8 +34,7 @@ enum
 {
 	ALL_PROCESSES,
 	MY_PROCESSES,
-	RUNNING_PROCESSES,
-	FAVORITE_PROCESSES,
+	ACTIVE_PROCESSES
 };
 
 #define NCPUSTATES 4
